/*
 * Author: Víctor Sánchez Sánchez (victorsanchez2@gmail.com - www.victorsanchez2.com)
 *
 * This file is part of FootballRankingGenerator.
 *
 * FootballRankingGenerator is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FootballRankingGenerator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FootballRankingGenerator.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

-- Creacion de la base de datos de Football Ranking Generator
CREATE DATABASE IF NOT EXISTS frg;

use frg;

-- Tabla con los equipos que forman
DROP TABLE IF EXISTS `equipos`;
CREATE TABLE IF NOT EXISTS `equipos` (
	`id` int NOT NULL auto_increment,
	`id_equipo` int NOT NULL,
	`nombre` varchar(64) NOT NULL,
	`anio_fundacion` int,
	`equipo2categoria` int,
	`posicion` int,
	`posicion_anterior` int,
	`presidente` varchar(128),
	`direccion` varchar(256),
	`telefono` int,
	`fax` int,
	`email` varchar(128),
	`web` varchar(128),

	PRIMARY KEY  (`id`),
	FULLTEXT KEY `idx_nombre_equipos` (`nombre`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_spanish_ci;

-- TRUNCATE TABLE `equipos`;
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`) VALUES (0,'Venta de Baños',1943);
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (1,'Gª Segoviana C.F.',1928,'http://www.gimnasticasegoviana.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (2,'Villaralbo C.F.',1952,'http://www.gcevillaralbo.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`presidente`,`direccion`,`telefono`,`fax`) VALUES (3,'C.D. Cebrereña',1949,'Ángel Sastre','Juan Carlos I, 4',918630112,918630112);
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (4,'C.D. Atco. Astorga',1944,'http://www.atleticoastorga.com.es');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (5,'S.D. Los Gatos de Iscar',1968,'http://www.cdlosgatosdeiscar.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (6,'C.D. Numancia B S.A.D B',1945,'http://www.cdnumancia.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (7,'Burgos C.F.',1994,'http://www.burgoscf.es');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (8,'Arandina C.F.',1987,'http://www.arandinacf.net');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`) VALUES (9,'Cristo Atco.',1987);
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (10,'C.U.D. Santa Marta',1987,'http://www.udsantamarta.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`direccion`,`telefono`,`fax`,`email`,`web`) VALUES (11,'Real Ávila C.F. S.A.D.',1923,'Ctra. de Sonsoles S/N',920227476,920227476,'realavilacf@realavila.e.telefonica.net','http:// www.realavila.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (12,'Atco. Tordesillas',1969,'http://www.atleticotordesillas.es');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (13,'S.D. Almazán',1967,'http://www.sdalmazan.tk');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (14,'C.D. Huracán Z',1954,'http://www.huracanz.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (15,'S.D. Ponferradina B',1922,'http://www.sdponferradina.com');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`) VALUES (16,'C.D. Aguilar',1947);
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`) VALUES (17,'Racing Lermeño',1984);
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (18,'Real Valladolid B',1972,'http://www.realvalladolid.es');
INSERT INTO equipos (`id_equipo`,`nombre`,`anio_fundacion`,`web`) VALUES (19,'C.D. Atco. Bembibre',1922,'http://www.atleticobembibre.com');

DROP TABLE IF EXISTS `jornada`;
CREATE TABLE IF NOT EXISTS `jornada` (
	`id` int NOT NULL auto_increment,
	`num_jornada` int NOT NULL,
	`num_partido` int NOT NULL,
	`equipo_local` varchar(64) NOT NULL,
	`equipo_visitante` varchar(64) NOT NULL,
	`goles_local` int DEFAULT NULL,
	`goles_visitante` int DEFAULT NULL,
	`puntos_local` int DEFAULT NULL,
	`puntos_visitante` int DEFAULT NULL,
	PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_spanish_ci;


-- Algoritmo para la generacion del calendario:
--
-- http://futbolymates.blogspot.com/
-- http://futbolymates.blogspot.com/2009/11/emparejamientos-y-calendario.html
-- TRUNCATE TABLE `jornada`;
-- Jornada Inicial (Se comienza a numerar desde 0):
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,0,18,17);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,1,15,11);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,2,19,0);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,3,7,13);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,4,3,9);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,5,10,1);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,6,12,16);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,7,6,4);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,8,2,14);
-- 		INSERT INTO jornada (`num_jornada`,`num_partido`,`equipo_local`,`equipo_visitante`) VALUES (1,9,5,8);


-- Tabla que guarda la clasificacion
DROP TABLE IF EXISTS `clasificacion`;
CREATE TABLE IF NOT EXISTS `clasificacion` (
	`id` int NOT NULL auto_increment,
	`id_equipo` int NOT NULL,

	`jugados` int NOT NULL,

	`puntos_t` int NOT NULL,		-- Puntos total
	`ganados_t` int NOT NULL,		-- Ganados total
	`empatados_t` int NOT NULL,	-- Empatados total
	`perdidos_t` int NOT NULL,	-- Perdidos total
	`goles_ft` int NOT NULL,		-- Goles favor total
	`goles_ct` int NOT NULL,		-- Goles contra total
	`diff_gt` int NOT NULL,			-- Diferencia goles total

	`puntos_c` int NOT NULL,		-- Puntos casa
	`ganados_c` int NOT NULL,		-- Ganados casa
	`empatados_c` int NOT NULL,	-- Empatados casa
	`perdidos_c` int NOT NULL,	-- Perdidos casa
	`goles_fc` int NOT NULL,		-- Goles favor casa
	`goles_cc` int NOT NULL,		-- Goles contra casa
	`diff_gc` int NOT NULL,			-- Diferencia goles casa

	`puntos_f` int NOT NULL,		-- Puntos fuera
	`ganados_f` int NOT NULL,		-- Ganados fuera
	`empatados_f` int NOT NULL,	-- Empatados fuera
	`perdidos_f` int NOT NULL,	-- Perdidos fuera
	`goles_ff` int NOT NULL,		-- Goles favor fuera
	`goles_cf` int NOT NULL,		-- Goles contra fuera
	`diff_gf` int NOT NULL,			-- Diferencia goles fuera

	PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_spanish_ci;

-- Inicializar la clasificacion poniendo todos los campos a 0
-- TRUNCATE TABLE `clasificacion`;
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
INSERT INTO clasificacion (`id_equipo`,`jugados`,`puntos_t`,`ganados_t`,`empatados_t`,`perdidos_t`,`goles_ft`,`goles_ct`,`diff_gt`,`puntos_c`,`ganados_c`,`empatados_c`,`perdidos_c`,`goles_fc`,`goles_cc`,`diff_gc`,`puntos_f`,`ganados_f`,`empatados_f`,`perdidos_f`,`goles_ff`,`goles_cf`,`diff_gf`) VALUES (19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);

